
// $Id: DocumentClassToolBar.cpp,v 1.9 2011/11/11 11:57:11 hpereira Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
****************************************************************************/

/*!
   \file DocumentClassToolBar.h
   \brief editor main window
   \author Hugo Pereira
   \version $Revision: 1.9 $
   \date $Date: 2011/11/11 11:57:11 $
*/

#include <QLabel>

#include "Application.h"
#include "Debug.h"
#include "DocumentClass.h"
#include "DocumentClassManager.h"
#include "DocumentClassToolBar.h"
#include "Singleton.h"



//________________________________________________________________
DocumentClassToolBar::DocumentClassToolBar( QWidget* parent ):
  CustomToolBar( "Document Class", parent, "DOCUMENT_CLASS_TOOLBAR" )
{

  Debug::Throw( "DocumentClassToolBar::DocumentClassToolBar.\n" );
  addWidget( combobox_ = new QComboBox( this ) );

  connect( &_comboBox(), SIGNAL( currentIndexChanged( int ) ), SLOT( _currentIndexChanged( int ) ) );
  connect( Singleton::get().application(), SIGNAL( documentClassesChanged() ), SLOT( _update() ) );

}

//________________________________________________________________
void DocumentClassToolBar::update( QString class_name )
{
  Debug::Throw( "DocumentClassToolBar::update.\n" );
  current_class_ = class_name;
  _comboBox().setCurrentIndex( _comboBox().findText( class_name ) );
}

//________________________________________________________________
void DocumentClassToolBar::_currentIndexChanged( int index )
{
  Debug::Throw( "DocumentClassToolBar::_currentIndexChanged.\n" );
  QString class_name( _comboBox().itemText( index ) );
  if( class_name == current_class_ ) return;
  current_class_ = class_name;
  emit documentClassSelected( class_name );
}

//________________________________________________________________
void DocumentClassToolBar::_update( void )
{
  Debug::Throw( "DocumentClassToolBar::update.\n" );

  // store current item
  QString current_class( _comboBox().currentText() );

  // clear box
  _comboBox().clear();

  // add all document classes
  const DocumentClassManager &manager( Singleton::get().application<Application>()->classManager() );
  const DocumentClassManager::List& classes( manager.classes() );
  for( DocumentClassManager::List::const_iterator iter = classes.begin(); iter != classes.end(); ++iter )
  { _comboBox().addItem( iter->name() ); }

  // try select old class if possible
  _comboBox().setCurrentIndex( _comboBox().findText( current_class ) );

}
